==> opennms-dao-api-18.0.0-20151105.091123-38-sources.jar: org/opennms/netmgt/dao/api/BridgeMacLinkDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.api;

import java.util.Date;
import java.util.List;

import org.opennms.netmgt.model.BridgeMacLink;
import org.opennms.netmgt.model.topology.BridgeMacTopologyLink;


/**
 * <p>BridgeMacLinkDao interface.</p>
 */
public interface BridgeMacLinkDao extends OnmsDao<BridgeMacLink, Integer> {
    
    public List<BridgeMacLink> findByNodeId(Integer id);

    public BridgeMacLink getByNodeIdBridgePortMac(Integer id, Integer port,String mac);

    public List<BridgeMacLink> findByMacAddress(String mac);

    void deleteByNodeIdOlderThen(Integer nodeiId, Date now);

    public List<BridgeMacTopologyLink> getAllBridgeLinksToIpAddrToNodes();

    public List<BridgeMacTopologyLink> getAllBridgeLinksToBridgeNodes();

}

==> opennms-dao-api-21.1.0-20190906.035230-84-sources.jar: org/opennms/netmgt/dao/api/BridgeMacLinkDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.api;

import java.util.Date;
import java.util.List;

import org.opennms.netmgt.model.BridgeMacLink;


/**
 * <p>BridgeMacLinkDao interface.</p>
 */
public interface BridgeMacLinkDao extends OnmsDao<BridgeMacLink, Integer> {
    
    public List<BridgeMacLink> findByNodeId(Integer id);

    public BridgeMacLink getByNodeIdBridgePortMac(Integer id, Integer port,String mac);

    public List<BridgeMacLink> findByNodeIdBridgePort(Integer id, Integer port);

    public List<BridgeMacLink> findByMacAddress(String mac);

    void deleteByNodeIdOlderThen(Integer nodeiId, Date now);

    void deleteByNodeId(Integer nodeiId);

}
